pub fn require_owner(account: &AccountView, owner: &Address) -> ProgramResultExpand description
Require that the account is owned by the given program.
pub fn require_owner(account: &AccountView, owner: &Address) -> ProgramResultRequire that the account is owned by the given program.