pub fn set_return_data(data: &[u8]) -> ProgramResultExpand description
Set return data for the current instruction.
Makes data available to the calling program via get_return_data().
Maximum 1024 bytes per Solana runtime limits.
pub fn set_return_data(data: &[u8]) -> ProgramResultSet return data for the current instruction.
Makes data available to the calling program via get_return_data().
Maximum 1024 bytes per Solana runtime limits.