#[repr(transparent)]pub struct UntypedAddress(pub [u8; 32]);Expand description
An untyped 32-byte address (interop bridge).
Useful for storing addresses where the account type is not known at compile time, or when interfacing with raw hopper-native APIs.
Tuple Fields
0: [u8; 32]Implementations