TailElement

Trait TailElement 

pub trait TailElement:
    TailCodec
    + Copy
    + Default
    + PartialEq { }
Element type accepted by #[tail(vec<T, N>)] in #[hopper::dynamic_account].

A tail element must have deterministic Hopper tail encoding, be cheap to copy into the fixed-capacity backing array, have a default empty slot value, and be comparable for generated push_unique_* / remove_* helpers.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> TailElement for T